import 'package:flutter_secure_storage/flutter_secure_storage.dart';

class AuthorizationPreferences {
  final FlutterSecureStorage _storage = const FlutterSecureStorage(
    aOptions: AndroidOptions(
      encryptedSharedPreferences: true,
      sharedPreferencesName: 'FUAP',
    ),
    iOptions: IOSOptions(accessibility: KeychainAccessibility.unlocked),
  );

  final _key = 'fuap_ed';

  Future<void> setExpirationDate(DateTime dateTime) async {
    return _storage.write(
      key: _key,
      value: dateTime.millisecondsSinceEpoch.toString(),
    );
  }

  Future<DateTime> getExpirationDate() async {
    final millisString = await _storage.read(key: _key);
    final millis = int.parse(millisString ?? '0');

    return DateTime.fromMillisecondsSinceEpoch(
      millis,
      isUtc: true,
    );
  }

  Future<void> clear() async {
    return _storage.deleteAll();
  }
}
