import 'package:rook_users/rook_users.dart';
import 'package:shared_preferences/shared_preferences.dart';

/// Helper class to manage rook_users preferences.
class UsersPreferences {
  SharedPreferences? _preferences;

  final String _rookUserKey = 'ROOK_USER';

  Future<bool> _init() async {
    _preferences ??= await SharedPreferences.getInstance();

    return true;
  }

  /// Saves the provided [RookUser] instance in preferences.
  ///
  /// This function will replace any existing values.
  Future<bool> saveRookUser(RookUser rookUser) async {
    await _init();

    final saved = await _preferences!.setString(
      '${_rookUserKey}_${rookUser.type.name}',
      rookUser.id,
    );

    return saved;
  }

  /// Retrieve the current [RookUser] from preferences. Or null if not found.
  Future<RookUser?> getRookUser(UserType userType) async {
    await _init();

    final id = _preferences!.getString('${_rookUserKey}_${userType.name}');

    if (id != null) {
      return RookUser(id: id, type: userType);
    } else {
      return null;
    }
  }

  /// Deletes the provided [UserType].
  Future<bool> deleteRookUser(UserType userType) async {
    await _init();

    final success =
        await _preferences!.remove('${_rookUserKey}_${userType.name}');

    return success;
  }
}
