import 'dart:convert';

/// This class represents a request to register a user in server.
///
/// * [sourceOfData] - Were the user account will be registered.
/// * [userID] - User unique identifier.
class CreateRookUserRequest {
  final String sourceOfData;
  final String userID;

  const CreateRookUserRequest({
    required this.sourceOfData,
    required this.userID,
  });

  String toJson() {
    final map = {
      'sources_of_data': sourceOfData,
      'user_id': userID,
    };

    return jsonEncode(map);
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is CreateRookUserRequest &&
          runtimeType == other.runtimeType &&
          sourceOfData == other.sourceOfData &&
          userID == other.userID;

  @override
  int get hashCode => sourceOfData.hashCode ^ userID.hashCode;

  @override
  String toString() {
    return 'RegisterRookUserRequest{sourceOfData: $sourceOfData, userID: $userID}';
  }
}
